@@ -39,8 +39,8 @@
 #include <gdata/gdata.h>
 
 #define EOG_POSTASA_RESOURCE_PREFIX "/org/gnome/eog/plugins/postasa"
-#define GTKBUILDER_CONFIG_FILE EOG_POSTASA_RESOURCE_PREFIX"/postasa-config.xml"
-#define GTKBUILDER_UPLOAD_FILE EOG_POSTASA_RESOURCE_PREFIX"/postasa-uploads.xml"
+#define GTKBUILDER_CONFIG_FILE EOG_POSTASA_RESOURCE_PREFIX"/postasa-config.ui"
+#define GTKBUILDER_UPLOAD_FILE EOG_POSTASA_RESOURCE_PREFIX"/postasa-uploads.ui"
 
 #define EOG_POSTASA_PLUGIN_MENU_ID "EogPluginPostasa"
 #define EOG_POSTASA_PLUGIN_ACTION "postasa-upload"
@@ -303,7 +303,7 @@ uploads_add_entry (EogPostasaPlugin *plugin, EogImage *image, GCancellable *canc
 					   2, size,
 					   3, 50, /* upload status: set to G_MAXINT when done, to 0 to not start */
 					   4, cancellable,
-					   5, _("Uploading..."),
+					   5, _("Uploading…"),
 					   -1); /* TODO: where should cancellabe, scaled_pixbuf be unref'd? don't worry about it since
 						   they'll exist until EoG exits anyway? or in eog_postasa_plugin_dispose()? */
 	g_free (uri);
@@ -611,7 +611,7 @@ picasaweb_login_cb (GtkWidget *login_button, gpointer _plugin)
 	gtk_widget_set_sensitive (GTK_WIDGET (plugin->priv->password_entry), FALSE);
 
 	/* TODO: want to handle passwords more securely */
-	gtk_label_set_text (plugin->priv->login_message, _("Logging in..."));
+	gtk_label_set_text (plugin->priv->login_message, _("Logging in…"));
 	g_cancellable_reset (plugin->priv->login_cancellable);
 
 #ifdef HAVE_LIBGDATA_0_9
@@ -774,6 +774,35 @@ login_get_dialog (EogPostasaPlugin *plugin)
 
 /*** EogPlugin Functions ***/
 
+static void
+eog_postasa_plugin_update_action_state (EogPostasaPlugin *plugin)
+{
+	EogPostasaPluginPrivate *priv = plugin->priv;
+	GAction *action;
+	EogThumbView *thumbview;
+	gboolean enable = FALSE;
+
+	thumbview = EOG_THUMB_VIEW (eog_window_get_thumb_view (priv->eog_window));
+
+	if (G_LIKELY (thumbview))
+	{
+		enable = (eog_thumb_view_get_n_selected (thumbview) != 0);
+	}
+
+	action = g_action_map_lookup_action (G_ACTION_MAP (priv->eog_window),
+					     EOG_POSTASA_PLUGIN_ACTION);
+	g_simple_action_set_enabled (G_SIMPLE_ACTION (action), enable);
+}
+
+static void
+_selection_changed_cb (EogThumbView *thumbview, gpointer user_data)
+{
+	EogPostasaPlugin *plugin = EOG_POSTASA_PLUGIN (user_data);
+
+	if (G_LIKELY (plugin))
+		eog_postasa_plugin_update_action_state (plugin);
+}
+
 /**
  * impl_activate:
  *
@@ -802,6 +831,12 @@ impl_activate (EogWindowActivatable *activatable)
 				 G_ACTION (action));
 	g_object_unref (action);
 
+	g_signal_connect (G_OBJECT (eog_window_get_thumb_view (plugin->priv->eog_window)),
+			  "selection-changed",
+			  G_CALLBACK (_selection_changed_cb),
+			  plugin);
+	eog_postasa_plugin_update_action_state (plugin);
+
 	/* Append entry to the window's gear menu */
 	menu = g_menu_new ();
 	g_menu_append (menu, _("Upload to PicasaWeb"),
@@ -850,6 +885,9 @@ impl_deactivate	(EogWindowActivatable *activatable)
 		}
 	}
 
+	g_signal_handlers_disconnect_by_func (eog_window_get_thumb_view (plugin->priv->eog_window),
+					      _selection_changed_cb, plugin);
+
 	/* Finally remove action */
 	g_action_map_remove_action (G_ACTION_MAP (plugin->priv->eog_window),
 				    EOG_POSTASA_PLUGIN_ACTION);
